@@ -1,7 +1,8 @@
 from argparse import ArgumentParser
-from dodo_commands.framework import Dodo
-from dodo_commands.framework.config import (load_global_config_parser,
-                                            write_global_config_parser)
+
+from dodo_commands import Dodo, CommandError
+from dodo_commands.framework.global_config import (load_global_config_parser,
+                                                   write_global_config_parser)
 
 
 def _args():
@@ -16,6 +17,10 @@ def _args():
 if Dodo.is_main(__name__, safe=False):
     args = _args()
     config = load_global_config_parser()
+
+    if args.key.count('.') != 1:
+        raise CommandError('The key should have the format <section>.<value>')
+
     section, key = args.key.split('.')
     if args.val:
         config.set(section, key, args.val)
